@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2014/11/05 10:20:13 $
- * $Revision: 1.215 $
+ * $Date: 2016/12/04 19:33:34 $
+ * $Revision: 1.219 $
  */
 
 #define L_MARKER '<'
@@ -204,10 +204,11 @@ chtype *copyChtype (const chtype *original)
    if (original != 0)
    {
       int len = chlen (original);
-      int x;
 
       if ((newstring = typeMallocN (chtype, len + 4)) != 0)
       {
+	 int x;
+
 	 for (x = 0; x < len; x++)
 	 {
 	    newstring[x] = original[x];
@@ -336,26 +337,26 @@ static int encodeAttribute (const char *string, int from, chtype *mask)
    {
       from++;
    }
-   else if (isdigit (CharOf (string[from + 1])) &&
-	    isdigit (CharOf (string[from + 2])))
+   else
    {
+      int digits;
+
+      pair = 0;
+      for (digits = 1; digits <= 3; ++digits)
+      {
+	 if (!isdigit (CharOf (string[1 + from])))
+	    break;
+	 pair *= 10;
+	 pair += DigitOf (string[++from]);
+      }
 #ifdef HAVE_START_COLOR
-      pair = DigitOf (string[from + 1]) * 10 + DigitOf (string[from + 2]);
+#define MAX_PAIR (int) (A_COLOR / (((~A_COLOR) << 1) & A_COLOR))
+      if (pair > MAX_PAIR)
+	 pair = MAX_PAIR;
       *mask = (chtype)COLOR_PAIR (pair);
 #else
       *mask = A_BOLD;
 #endif
-      from += 2;
-   }
-   else if (isdigit (CharOf (string[from + 1])))
-   {
-#ifdef HAVE_START_COLOR
-      pair = DigitOf (string[from + 1]);
-      *mask = (chtype)COLOR_PAIR (pair);
-#else
-      *mask = A_BOLD;
-#endif
-      from++;
    }
    return from;
 }
@@ -464,28 +465,27 @@ chtype *char2Chtype (const char *string, int *to, int *align)
    chtype attrib;
    chtype lastChar;
    chtype mask;
-   int adjust;
-   int from;
-   int insideMarker;
-   int len;
-   int pass;
-   int start;
-   int used;
-   int x;
 
    (*to) = 0;
    *align = LEFT;
 
    if (string != 0 && *string != 0)
    {
-      len = (int)strlen (string);
-      used = 0;
+      int len = (int)strlen (string);
+      int pass;
+      int used = 0;
       /*
        * We make two passes because we may have indents and tabs to expand, and
        * do not know in advance how large the result will be.
        */
       for (pass = 0; pass < 2; pass++)
       {
+	 int insideMarker;
+	 int from;
+	 int adjust;
+	 int start;
+	 int x = 3;
+
 	 if (pass != 0)
 	 {
 	    if ((result = typeMallocN (chtype, used + 2)) == 0)
@@ -498,7 +498,6 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	 attrib = A_NORMAL;
 	 start = 0;
 	 used = 0;
-	 x = 3;
 
 	 /* Look for an alignment marker.  */
 	 if (*string == L_MARKER)
@@ -844,10 +843,11 @@ char *chtype2Char (const chtype *string)
    if (string != 0)
    {
       int len = chlen (string);
-      int x;
 
       if ((newstring = typeMallocN (char, len + 1)) != 0)
       {
+	 int x;
+
 	 for (x = 0; x < len; x++)
 	 {
 	    newstring[x] = (char)CharOf (string[x]);
@@ -916,8 +916,6 @@ void stripWhiteSpace (EStripType stripType, char *string)
 {
    /* Declare local variables.  */
    size_t stringLength = 0;
-   unsigned alphaChar = 0;
-   unsigned x;
 
    /* Make sure the string is not null.  */
    if (string != 0
@@ -926,6 +924,9 @@ void stripWhiteSpace (EStripType stripType, char *string)
       /* Strip leading whitespace */
       if (stripType == vFRONT || stripType == vBOTH)
       {
+	 unsigned alphaChar = 0;
+	 unsigned x;
+
 	 /* Find the first non-whitespace character.  */
 	 while (string[alphaChar] == ' ' || string[alphaChar] == '\t')
 	 {
@@ -969,18 +970,15 @@ static unsigned countChar (const char *string, int separator)
 char **CDKsplitString (const char *string, int separator)
 {
    char **result = 0;
-   const char *first;
    char *temp;
-   unsigned item;
-   unsigned need;
 
    if (string != 0 && *string != 0)
    {
-      need = countChar (string, separator) + 2;
+      unsigned need = countChar (string, separator) + 2;
       if ((result = typeMallocN (char *, need)) != 0)
       {
-	 item = 0;
-	 first = string;
+	 unsigned item = 0;
+	 const char *first = string;
 	 for (;;)
 	 {
 	    while (*string != 0 && *string != separator)
@@ -1241,21 +1239,19 @@ int CDKgetDirectoryContents (const char *directory, char ***list)
  */
 int searchList (CDK_CSTRING2 list, int listSize, const char *pattern)
 {
-   /* Declare local variables.  */
-   size_t len;
    int Index = -1;
-   int x, ret;
 
    /* Make sure the pattern isn't null. */
    if (pattern != 0)
    {
-      len = strlen (pattern);
+      size_t len = strlen (pattern);
+      int x;
 
       /* Cycle through the list looking for the word. */
       for (x = 0; x < listSize; x++)
       {
 	 /* Do a string compare. */
-	 ret = strncmp (list[x], pattern, len);
+	 int ret = strncmp (list[x], pattern, len);
 
 	 /*
 	  * If 'ret' is less than 0, then the current word is alphabetically
@@ -1287,7 +1283,6 @@ int checkForLink (const char *line, char *filename)
 {
    int len = 0;
    int fPos = 0;
-   int x = 3;
 
    /* Make sure the line isn't null. */
    if (line == 0)
@@ -1299,6 +1294,8 @@ int checkForLink (const char *line, char *filename)
    /* Strip out the filename. */
    if (line[0] == L_MARKER && line[1] == 'F' && line[2] == '=')
    {
+      int x = 3;
+
       /* Strip out the filename.  */
       while (x < len)
       {
@@ -1322,15 +1319,17 @@ int checkForLink (const char *line, char *filename)
 char *baseName (char *pathname)
 {
    char *base = 0;
-   size_t pathLen;
-   size_t x;
 
    if (pathname != 0
        && *pathname != '\0'
        && (base = copyChar (pathname)) != 0)
    {
+      size_t pathLen;
+
       if ((pathLen = strlen (pathname)) != 0)
       {
+	 size_t x;
+
 	 for (x = pathLen - 1; x != 0; --x)
 	 {
 	    /* Find the last '/' in the pathname. */
@@ -1353,14 +1352,13 @@ char *dirName (char *pathname)
 {
    char *dir = 0;
    size_t pathLen;
-   size_t x;
 
    /* Check if the string is null.  */
    if (pathname != 0
        && (dir = copyChar (pathname)) != 0
        && (pathLen = strlen (pathname)) != 0)
    {
-      x = pathLen;
+      size_t x = pathLen;
       while ((dir[x] != '/') && (x > 0))
       {
 	 dir[x--] = '\0';
