@@ -1,4 +1,4 @@
-/* $Id: preprocess_ex.c,v 1.18 2012/03/21 23:20:40 tom Exp $ */
+/* $Id: preprocess_ex.c,v 1.20 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -16,15 +16,12 @@ int main (void)
    /* *INDENT-EQLS* */
    CDKSCREEN *cdkscreen = 0;
    CDKENTRY *widget     = 0;
-   WINDOW *cursesWin    = 0;
    const char *title    = "<C>Type in anything you want\n<C>but the dreaded letter </B>G<!B>!";
    char *info;
    const char *mesg[10];
    char temp[256];
 
-   /* Set up CDK. */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    /* Start CDK colors. */
    initCDKColor ();
@@ -56,7 +53,7 @@ int main (void)
       mesg[0] = "<C>You hit escape. No information passed back.";
       mesg[1] = "",
 	 mesg[2] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 3);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 3);
    }
    else if (widget->exitType == vNORMAL)
    {
@@ -65,7 +62,7 @@ int main (void)
       mesg[1] = temp;
       mesg[2] = "";
       mesg[3] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 4);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 4);
    }
 
    /* Clean up and exit. */
@@ -75,32 +72,32 @@ int main (void)
    ExitProgram (EXIT_SUCCESS);
 }
 
-static int entryPreProcessCB (EObjectType cdkType GCC_UNUSED,
-			      void *object,
+static int entryPreProcessCB (EObjectType cdkType GCC_UNUSED, void *object,
 			      void *clientData GCC_UNUSED,
 			      chtype input)
 {
-   /* *INDENT-EQLS* */
-   CDKENTRY *entry       = (CDKENTRY *)object;
-   CDKDIALOG *widget     = 0;
-   const char *buttons[] =
-   {
-      "OK"
-   };
-   int buttonCount       = 1;
-   int lines             = 0;
-   const char *mesg[5];
+   CDKENTRY *entry = (CDKENTRY *)object;
 
    /* Check the input. */
    if ((input == 'g') || (input == 'G'))
    {
+      /* *INDENT-EQLS* */
+      CDKDIALOG *widget     = 0;
+      int buttonCount       = 1;
+      int lines             = 0;
+      const char *buttons[] =
+      {
+	 "OK"
+      };
+      const char *mesg[5];
+
       mesg[lines++] = "<C><#HL(30)>";
       mesg[lines++] = "<C>I told you </B>NOT<!B> to type G";
       mesg[lines++] = "<C><#HL(30)>";
 
       widget = newCDKDialog (ScreenOf (entry), CENTER, CENTER,
-			     (CDK_CSTRING2) mesg, lines,
-			     (CDK_CSTRING2) buttons, buttonCount,
+			     (CDK_CSTRING2)mesg, lines,
+			     (CDK_CSTRING2)buttons, buttonCount,
 			     A_REVERSE, FALSE, TRUE, FALSE);
       activateCDKDialog (widget, 0);
       destroyCDKDialog (widget);
