@@ -1,4 +1,4 @@
-/* $Id: template_ex.c,v 1.12 2012/03/21 23:35:07 tom Exp $ */
+/* $Id: template_ex.c,v 1.13 2016/12/04 15:22:16 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -14,7 +14,6 @@ int main (int argc, char **argv)
    /* *INDENT-EQLS* */
    CDKSCREEN *cdkscreen         = 0;
    CDKTEMPLATE *phoneNumber     = 0;
-   WINDOW *cursesWin            = 0;
    const char *title            = "<C>Title";
    const char *label            = "</5>Phone Number:<!5>";
    const char *Overlay          = "</B/6>(___)<!6> </5>___-____";
@@ -28,9 +27,7 @@ int main (int argc, char **argv)
 
    CDKparseParams (argc, argv, &params, CDK_MIN_PARAMS);
 
-   /* Set up CDK */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    /* Start CDK Colors. */
    initCDKColor ();
