@@ -2,14 +2,14 @@
 
 /*
  * $Author: tom $
- * $Date: 2005/12/30 00:17:57 $
- * $Revision: 1.2 $
+ * $Date: 2012/03/21 08:44:22 $
+ * $Revision: 1.4 $
  */
 
 /*
  * This pops up a message.
  */
-void popupLabel (CDKSCREEN *screen, char **mesg, int count)
+void popupLabel (CDKSCREEN *screen, CDK_CSTRING2 mesg, int count)
 {
    CDKLABEL *popup = 0;
    int oldCursState;
@@ -18,19 +18,19 @@ void popupLabel (CDKSCREEN *screen, char **mesg, int count)
    /* Create the label. */
    popup = newCDKLabel (screen, CENTER, CENTER, mesg, count, TRUE, FALSE);
 
-   oldCursState = curs_set(0);
+   oldCursState = curs_set (0);
    /* Draw it on the screen. */
    drawCDKLabel (popup, TRUE);
 
    /* Wait for some input. */
    keypad (popup->win, TRUE);
-   getchCDKObject (ObjOf(popup), &functionKey);
+   getchCDKObject (ObjOf (popup), &functionKey);
 
    /* Kill it. */
    destroyCDKLabel (popup);
 
    /* Clean the screen. */
-   curs_set(oldCursState);
+   curs_set (oldCursState);
    eraseCDKScreen (screen);
    refreshCDKScreen (screen);
 }
@@ -38,7 +38,7 @@ void popupLabel (CDKSCREEN *screen, char **mesg, int count)
 /*
  * This pops up a message.
  */
-void popupLabelAttrib (CDKSCREEN *screen, char **mesg, int count, chtype attrib)
+void popupLabelAttrib (CDKSCREEN *screen, CDK_CSTRING2 mesg, int count, chtype attrib)
 {
    CDKLABEL *popup = 0;
    int oldCursState;
@@ -46,21 +46,21 @@ void popupLabelAttrib (CDKSCREEN *screen, char **mesg, int count, chtype attrib)
 
    /* Create the label. */
    popup = newCDKLabel (screen, CENTER, CENTER, mesg, count, TRUE, FALSE);
-   setCDKLabelBackgroundAttrib(popup, attrib);
+   setCDKLabelBackgroundAttrib (popup, attrib);
 
-   oldCursState = curs_set(0);
+   oldCursState = curs_set (0);
    /* Draw it on the screen. */
    drawCDKLabel (popup, TRUE);
 
    /* Wait for some input. */
    keypad (popup->win, TRUE);
-   getchCDKObject (ObjOf(popup), &functionKey);
+   getchCDKObject (ObjOf (popup), &functionKey);
 
    /* Kill it. */
    destroyCDKLabel (popup);
 
    /* Clean the screen. */
-   curs_set(oldCursState);
+   curs_set (oldCursState);
    eraseCDKScreen (screen);
    refreshCDKScreen (screen);
 }
