@@ -2,18 +2,23 @@
 
 /*
  * $Author: tom $
- * $Date: 2005/12/27 01:05:44 $
- * $Revision: 1.3 $
+ * $Date: 2012/03/22 00:39:54 $
+ * $Revision: 1.4 $
  */
 
 /*
  * This allows the user to view a file.
  */
-int viewFile (CDKSCREEN *screen, char *title, char *filename, char **buttons, int buttonCount)
+int viewFile (CDKSCREEN *screen,
+	      const char *title,
+	      const char *filename,
+	      CDK_CSTRING2 buttons,
+	      int buttonCount)
 {
+   /* *INDENT-EQLS* */
+   int lines            = 0;
+   char **info          = 0;
    int result;
-   int lines		= 0;
-   char **info		= 0;
 
    /* Open the file and read the contents. */
    lines = CDKreadFile (filename, &info);
@@ -26,7 +31,10 @@ int viewFile (CDKSCREEN *screen, char *title, char *filename, char **buttons, in
    else
    {
 
-      result = viewInfo(screen, title, info, lines, buttons, buttonCount, TRUE);
+      result = viewInfo (screen, title,
+			 (CDK_CSTRING2) info, lines,
+			 buttons, buttonCount,
+			 TRUE);
       CDKfreeStrings (info);
    }
    return result;
